local frame = CreateFrame("Frame", "AutoActionCam")
local options = { 
    "full",     "basic",         "default",    "off",    
    "headMove", "heavyHeadMove", "lowHeadMove", "noHeadMove";  
    "focusOn", "focusOff"
}

-- Color the message and print it in the chat window
function printInChat(msg)
    DEFAULT_CHAT_FRAME:AddMessage(msg, 127/255, 219/255, 1.0)
end

-- Register events
frame:RegisterEvent("ADDON_LOADED")
frame:RegisterEvent("PLAYER_LOGIN")

-- Function to call when a registered event is raised
function frame:OnEvent(event, ...)
    if event == "ADDON_LOADED" and ... == "AutoActionCam" then
        if CamSetting == nil then -- First load
            CamSetting = { }
            CamSetting["mode"] = "full"
            CamSetting["head"] = "heavyHeadMove"
            CamSetting["focus"] = "focusOn"
            printInChat("AAC loaded for the first time, default settings set.")
        end
    elseif event == "PLAYER_LOGIN" then -- Load settings
        ConsoleExec("ActionCam " .. CamSetting["mode"])
        ConsoleExec("ActionCam " .. CamSetting["head"])
        ConsoleExec("ActionCam " .. CamSetting["focus"])
    end
end
frame:SetScript("OnEvent", frame.OnEvent)

SLASH_AAC1 = "/aac"
function slashHandler(msg)
    if msg == "reset" then -- reset options
        CamSetting = nil
        printInChat("AAC reset to default settings, please use /reload")
    end

    if msg == "profile" then -- Print current settings
        printInChat("AAC is currently loaded with the following settings")
        printInChat("- Mode: " .. CamSetting["mode"])
        printInChat("- Head movement: " .. CamSetting["head"])
        printInChat("- Focus: " .. CamSetting["focus"])
    end
    
    if msg == "list" then -- Help message
        printInChat("Available options for AAC")
        printInChat("- ActionCam mode")
        printInChat("    full (default), basic, default, off")
        printInChat("- Head movement intensity")
        printInChat("    headMove (default), heavyHeadMove, lowHeadMove, noHeadMove")
        printInChat("- Focus target")
        printInChat("    focusOn (default), focusOff")
    end
    
    for i = 1, 12 do
        if msg == options[i] then
            if i >= 1 and i <= 4 then -- ActionCam mode
                CamSetting["mode"] = msg
                ConsoleExec("ActionCam " .. CamSetting["mode"])
                break
            elseif i >= 5 and i <= 8 then -- Intensity of head movement
                CamSetting["head"] = msg
                ConsoleExec("ActionCam " .. CamSetting["head"])
                break
            elseif i >= 9 and i <= 10 then -- Which target to focus
                CamSetting["focus"] = msg
                ConsoleExec("ActionCam " .. CamSetting["focus"])
                break
            end
        end
    end
    
    if msg == "" then
        printInChat("Syntax: /aac <option> with option")
        printInChat("- profile: print the current settings")
        printInChat("- list: prints all available settings")
        printInChat("- reset: resets the profile to default settings")
    end
end
SlashCmdList["AAC"] = slashHandler
